@@ -61,9 +61,9 @@ class AnnotatedWord(Word):
                     self.__metamorphicParse = MetamorphicParse(layerValue)
                 elif layerType == "namedEntity":
                     self.__namedEntityType = NamedEntityType.getNamedEntityType(layerValue)
-                elif layerType == "propBank":
+                elif layerType == "propbank" or layerType == "propBank":
                     self.__argument = Argument(layerValue)
-                elif layerType == "framenet":
+                elif layerType == "framenet" or layerType == "frameNet":
                     self.__frameElement = FrameElement(layerValue)
                 elif layerType == "shallowParse":
                     self.__shallowParse = layerValue
@@ -273,7 +273,7 @@ class AnnotatedWord(Word):
         argument : Argument
             New semantic role tag of the word.
         """
-        if self.__argument is not None:
+        if argument is not None:
             self.__argument = Argument(argument)
         else:
             self.__argument = None
@@ -298,8 +298,8 @@ class AnnotatedWord(Word):
         frameElement : str
             New framenet tag of the word.
         """
-        if self.__frameElement is not None:
-            self.__frameElement = Argument(frameElement)
+        if frameElement is not None:
+            self.__frameElement = FrameElement(frameElement)
         else:
             self.__frameElement = None
 
